@@ -1,9 +1,10 @@
-use frameobject::PyFrameObject;
 use libc::{c_char, c_int, c_void};
-use object::PyObject;
-use pyport::Py_ssize_t;
-use pystate::{PyThreadState, Py_tracefunc};
-use pythonrun::PyCompilerFlags;
+
+use crate::frameobject::PyFrameObject;
+use crate::object::PyObject;
+use crate::pyport::Py_ssize_t;
+use crate::pystate::{PyThreadState, Py_tracefunc};
+use crate::pythonrun::PyCompilerFlags;
 
 #[cfg_attr(windows, link(name = "pythonXY"))]
 extern "C" {
