@@ -1,5 +1,19 @@
 #![no_std]
-#![allow(non_camel_case_types, non_upper_case_globals, non_snake_case, unused_parens)]
+#![allow(
+    non_camel_case_types,
+    non_upper_case_globals,
+    non_snake_case,
+    unused_parens,
+    clippy::missing_safety_doc,
+    clippy::transmute_ptr_to_ptr,
+    clippy::unused_unit,
+    clippy::identity_op
+)]
+
+// Macro for marking parts of the Python headers as ignored.
+macro_rules! ignore {
+    ( $( $_tokens:tt )* ) => {};
+}
 
 pub use crate::boolobject::*;
 pub use crate::bufferobject::*;
